HTML Compatibility
==================

Three HTML compatibility tools related to epijats are:

* [Baseprint Render Of Last Resort](https://gitlab.com/perm.pub/brolr),
* [utility to diff a roundtrip through DOMParser and then DOM XML serialization](./domparse/.),
* and <./cathead/head.html>.
